// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "AssetManager.hpp"
#include "assert/assert.hpp"

using namespace Dawn;

void AssetManager::init(const std::shared_ptr<Game> &game) {
  assertNotNull(game, "Game is NULL?");
  this->game = game;
}

void AssetManager::update() {
  auto copyPendingAssets = pendingAssetLoaders;
  auto itPending = copyPendingAssets.begin();
  while(itPending != copyPendingAssets.end()) {
    auto loader = *itPending;
    
    loader->updateSync();
    loader->updateAsync();
    loader->updateSync();

    if(!loader->loaded) {
      ++itPending;
      continue;
    }
    
    finishedAssetLoaders.push_back(loader);
    auto it = std::find(
      pendingAssetLoaders.begin(),
      pendingAssetLoaders.end(),
      loader
    );
    assertTrue(it != pendingAssetLoaders.end(), "Loader not found?");
    pendingAssetLoaders.erase(it);
    ++itPending;
  }
}

void AssetManager::remove(const std::shared_ptr<AssetLoader> loader) {
  for(
    auto it = pendingAssetLoaders.begin();
    it != pendingAssetLoaders.end();
    it++
  ) {
    if(*it != loader) continue;
    pendingAssetLoaders.erase(it);
    return;
  }

  for(
    auto it = finishedAssetLoaders.begin();
    it != finishedAssetLoaders.end();
    it++
  ) {
    if(it->lock() != loader) continue;
    finishedAssetLoaders.erase(it);
    return;
  }
}

bool_t AssetManager::isEverythingLoaded() {
  return pendingAssetLoaders.size() == 0;
}

std::shared_ptr<Game> AssetManager::getGame() {
  auto g = game.lock();
  assertNotNull(g, "Game is NULL?");
  return g;
}

AssetManager::~AssetManager() {
  
}