// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "StringLoader.hpp"

using namespace Dawn;

const std::string StringLoader::ASSET_TYPE = "string";

StringLoader::StringLoader(
  const std::shared_ptr<AssetManager> assetManager,
  const std::string name
) :
  AssetLoader(assetManager, name),
  loader(name),
  state(StringLoaderState::INITIAL)
{
}

void StringLoader::updateSync() {
}

void StringLoader::updateAsync() {
  if(this->state != StringLoaderState::INITIAL) return;
  this->state = StringLoaderState::LOADING_STRING;
  this->data = this->loader.getEntireContentsAsString();
  this->state = StringLoaderState::DONE;
  this->loaded = true;
}

std::string StringLoader::getAssetType() const {
  return StringLoader::ASSET_TYPE;
}

StringLoader::~StringLoader() {
}