// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "LoaderForSceneItems.hpp"
#include "scene/Scene.hpp"

namespace Dawn {
  enum class SceneLoaderState {
    INITIAL,
    LOADING_JSON,
    LOADING_DEPENDENCIES,
    PENDING_STAGE,
    DONE
  };

  class SceneLoader : public LoaderForSceneItems {
    protected:
      SceneLoaderState state;

    public:
      const static std::string ASSET_TYPE;

      SceneLoader(
        const std::shared_ptr<AssetManager> assetManager,
        const std::string name
      );
      
      void updateSync() override;
      void updateAsync() override;
      std::string getAssetType() const override;

      /**
       * Returns the Scene that was loaded, or nullptr if not loaded.
       * 
       * @return The loaded scene.
       */
      std::shared_ptr<Scene> getScene();

      ~SceneLoader();
  };
}