// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "component/display/material/Material.hpp"
#include "display/shader/SimpleTexturedShader.hpp"
#include "display/Texture.hpp"

namespace Dawn {
  class SimpleTexturedMaterial : public Material {
    private:
      struct SimpleTexturedShaderData data;
      std::shared_ptr<Texture> texture;

    protected:
      std::vector<std::shared_ptr<IShaderBase>> getLockedShaders(
        ShaderManager &shaderManager
      ) override;

    public:
      void load(std::shared_ptr<SceneLoadContext> ctx) override;
      
      /**
       * Returns the color of this material.
       */
      struct Color getColor();

      /**
       * Returns the texture of this material.
       * 
       * @return The texture of this material.
       */
      std::shared_ptr<Texture> getTexture();

      /**
       * Sets the texture of this material.
       * 
       * @param texture The texture to set.
       */
      void setTexture(const std::shared_ptr<Texture> texture);

      /**
       * Sets the color of this material.
       * 
       * @param color The color to set.
       */
      void setColor(const struct Color color);

      std::vector<std::shared_ptr<IRenderPass>> getPasses(
        struct RenderPassContext &ctx
      ) override;
  };
}