// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "MeshComponent.hpp"

namespace Dawn {
  class QuadMeshComponent final : public MeshComponent {
    protected:
      glm::vec4 positions;
      glm::vec4 uvs;
    
      void meshLoad(std::shared_ptr<SceneLoadContext> ctx) override;
      void meshBuffer(std::shared_ptr<Mesh> mesh) override;

    public:
      /**
       * Sets the positions of the quad.
       * 
       * @param positions The positions of the quad.
       */
      void setPositions(const glm::vec4 &positions);

      /**
       * Sets the UVs of the quad.
       * 
       * @param uvs The UVs of the quad.
       */
      void setUVs(const glm::vec4 &uvs);
  };
}