// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "display/Texture.hpp"
#include "TrueTypeCharacter.hpp"
#include "display/mesh/Mesh.hpp"
#include <ft2build.h>
#include FT_FREETYPE_H

namespace Dawn {
  class TrueTypeTexture final {
    private:
      FT_Face face;

    public:
      uint32_t fontSize;
      std::shared_ptr<Texture> texture;
      std::unordered_map<wchar_t, struct TrueTypeCharacter> characterData;

      /**
       * Construct a new New True Type Face Texture object
       * 
       * @param fontSize Size of the font.
       */
      TrueTypeTexture(const uint32_t &fontSize);

      /**
       * Sets the face for this texture.
       * 
       * @param face Face to set.
       */
      void setFace(const FT_Face &face);

      /**
       * Returns the character data for the given character.
       * 
       * @param c Character to get data for.
       * @return The Character data for the given character.
       */
      struct TrueTypeCharacter getCharacterData(const wchar_t &c);

      /**
       * Buffers a string to the given mesh.
       * 
       * @param mesh Mesh to buffer to.
       * @param text Text to buffer.
       * @param position Position to buffer to.
       * @param flipY Whether or not to flip the Y axis.
       * @return The size of the string.
       */
      glm::vec2 bufferStringToMesh(
        std::shared_ptr<Mesh> mesh,
        const std::wstring text,
        glm::vec2 &position,
        const bool_t flipY = false
      );

      /**
       * Destroys this true type face texture.
       */
      ~TrueTypeTexture();
  };
}