// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "display/mesh/Mesh.hpp"

#define PLANE_VERTICE_PER_SEGMENT 4
#define PLANE_INDICE_PER_SEGMENT 6

namespace Dawn {
  class PlaneMesh {
    public:
      /**
       * Buffers a plane mesh into the provided mesh.
       * 
       * @param mesh The mesh to buffer the plane into.
       * @param planeSize The size of the plane.
       * @param columns The number of columns.
       * @param rows The number of rows.
       * @param uv The UV coordinates of the plane.
       */
      static void buffer(
        const std::shared_ptr<Mesh> mesh,
        const glm::vec2 planeSize,
        const int32_t columns,
        const int32_t rows,
        const glm::vec4 uv = glm::vec4(0.0f, 0.0f, 1.0f, 1.0f)
      );
  };
}